Changelog
=========

1.0.0-dev_ (Unreleased)
-----------------------
- TBD

0.1.0, 2017-03-18
-----------------
- Initial Split from `VSGen 0.3.0`_.

.. _1.0.0-dev: https://github.com/dbarsam/python-vsgen/compare/0.1.0...HEAD
.. _VSGen 0.3.0: https://github.com/dbarsam/python-vsgen/releases/tag/0.3.0
